@@ -86,7 +86,7 @@ class API(Sqlite3):
                 except KeyError:
                     pass
 
-            if table_fields and field not in table_fields:
+            if table_fields and field not in table_fields and field != "id":
                 raise Sqlite3ApiError(
                     f"Поле `{field}` не найдено в таблице `{table_name}`"
                 )
